m4ri: fast arithmetic with dense matrices over GF(2)
====================================================

Description
-----------

M4RI: Library for matrix multiplication, reduction and inversion over
GF(2). (See also m4ri/README for a brief overview.)

License
-------

-  GNU General Public License Version 2 or later (see src/COPYING)


Upstream Contact
----------------

-  Authors: Martin Albrecht et al.
-  Email: <m4ri-devel@googlegroups.com>
-  Website: https://bitbucket.org/malb/m4ri
